@@ -1740,6 +1740,22 @@ def df_graph_telegram_features (DiG, nodes_participants_df):
     return df_graph_features
 
 ###----------------------Contextual Analysis Telegram -----------------------###
+def detectLanguge(msg):
+    lan=[]
+    for i in range(len(msg)):
+        x=( re.sub("[^a-zA-Z]", " ",str(msg.message.iloc[i])))
+        x=re.sub(' +', ' ', x)
+        if x == 'None':
+            lan.append('Not defined')
+        elif x == '':
+            lan.append('Not defined')
+        elif x == ' ':
+            lan.append('Not defined')
+        else:
+            lan.append(detect(x)) 
+    
+    msg['language'] = lan    
+    return msg
 
 def translateToEnglish(msg):
     translator = Translator()
@@ -1772,7 +1788,7 @@ def cosine_distance_countvectorizer_method(s1, s2):
     
     # distance of sifomilarity
     cosine = distance.cosine(text_to_vector_v1, text_to_vector_v2)
-    cosine_similarity = round((1-cosine),2)
+    cosine_similarity = round((1-cosine),4)
     #print('Similarity of two sentences are equal to ',round((1-cosine)*100,2),'%')
     return cosine_similarity
 
@@ -1807,12 +1823,23 @@ def hastags_preprocessing(msg):
     msg['hashtags'] = l
     return msg
 
+def hashtags_content_similarity(msg, corpus):
+    l=[]
+    for i in range(len(msg)):
+        if msg.hashtags.iloc[i] != 'no hashtags':
+            l.append(cosine_distance_countvectorizer_method(str(msg.hashtags.iloc[i]), corpus)*100)
+        else:
+            l.append(0)
+    msg['hashtags_terrorist_similarity'] = l
+    return msg
+
 def contextual_analysis_telegram(messages, corpus):
     messages = detectLanguge(messages)
     messages = translateToEnglish(messages)
     messages = detect_hastags(messages)
     messages = hastags_preprocessing(messages)
     messages = content_similitarity(messages, corpus)
+    messages = hashtags_content_similarity(messages, corpus)
     return messages
 
    
